Natural Earth » Blog Archive » Admin 0 – Countries - Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales

#

Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales
Search for:

- Home
- Features
- Downloads
- Blog
- Issues
- Corrections
- About

## Admin 0 – Countries

There are 258 countries in the world. Greenland as separate from Denmark. Most users will want this file instead of sovereign states, though some users will want map units instead when needing to distinguish overseas regions of France.

Natural Earth shows de facto boundaries by default according to who controls the territory, versus de jure.

Download countries (210.08 KB) version 5.1.1
Download without boundary lakes (212.3 KB) version 5.1.1

About

Countries distinguish between metropolitan (homeland) and independent and semi-independent portions of sovereign states. If you want to see the dependent overseas regions broken out (like in ISO codes, see France for example), use map units instead.

Each country is coded with a world region that roughly follows the United Nations setup.

Includes some thematic data from the United Nations, U.S. Central Intelligence Agency, and elsewhere.

Disclaimer

Natural Earth Vector draws boundaries of countries according to defacto status. We show who actually controls the situation on the ground. Please feel free to mashup our disputed areas (link) theme to match your particular political outlook.

Known Problems

None.

Version History

- 5.1.1
- 5.1.0
- 5.0.1
- 5.0.0
- 4.1.0
- 4.0.0
- 2.0.0
- 1.4.0
- 1.3.0
- 1.1.0

The master changelog is available on Github »

This entry was posted on Monday, September 21st, 2009 at 10:21 am and is filed under 110m-cultural-vectors. You can follow any responses to this entry through the RSS 2.0 feed. Both comments and pings are currently closed.

- Comments (3)
- Trackbacks

1. Getting rasters into shape from R | John Baumgartner's blog says:
   July 26, 2012 at 11:32 pm

   […] earlier. It’s the result of a conversion of a polygon shapefile of country boundaries (from Natural Earth, a fantastic, public domain, physical/cultural spatial data source) to a raster data […]

2. jQUERY e Mappe: jVectorMap | SimPoli says:
   February 28, 2013 at 5:42 am

   […] Le mappe sono scaricate da https://www.naturalearthdata.com […]

3. SimPoli » jQUERY e Mappe: jVectorMap says:
   March 13, 2013 at 2:52 am

   […] Le mappe sono scaricate da https://www.naturalearthdata.com […]